<html>
<head>
<title>SEARCH BOT</title>
</head>
<body>
<form method="GET">
<input id="search-query" name="search-query" type="search" />
<input id="submit" type="submit" name="Submit" />
</form>
<a id="url" href="{{url_body}}" target="_blank"  style="display:none;>Hi</a>
<script>
alert("jjsr");
document.getElementById("url").click();
alert("done");
</body>
</html>
