l:root{
--background-color: red;

}
html{
height:100%;
width:100%;
}
body{
background: linear-gradient(#0097,#0437);
display:flex;
align-items: center;
justify-content:center;
flex-direction: column;
gap:0vw;
width:100%;
}
*{
margin:0px;
padding:5px;
}
#search-container{
width:95%;
}
form{
display:flex;

}
#search-bar{
height:3vw;
font-size:4vw;
width:82%;
height:12vw;
border-top-left-radius:5vw;
border-bottom-left-radius:5vw;
}
#submit{
height:3vw;
font-size:4vw;
/*width:14%;*/
height:12vw;
border-top-right-radius:5vw;
border-bottom-right-radius:5vw;
}
.results-container{
width:95%;
}
.result-box{
overflow:scroll;
background:linear-gradient(90deg,#0099,#0439);
display:flex;
width:100%;
height:30vw;
flex-direction: column;
gap:0px;
border: 5px solid #0309;
border-radius:3vw;
padding:5px;
}
.url-icon{
display:flex;
align-items:space-between;
gap:2vw;
padding:0px;
}
.box-heading{
display:inline;
font-size:6vw;
padding:0px;
color:#9999;
}
.box-description{
display:inline;
font-size:4vw;
padding:0px;
}
@keyframes hi{
0%{
background:red;
}
50%{
background:blue;
}
100%{
background:red;
}
}

