<html>
<head>
<title>Admin Panel</title>
</head>
<body
<!-- Jai Jai Siya Ram!-->
<h1>Admin Panel<h1>
<form method="POST">
<select id= "operation" name="operation" >
<option value="insert">Insert</option>
<option value="update">Update</option>
<option value="delete">Delete</option>
</select>
<input id="company" placeholder="Enter Company Name" name="company-name" type="text" />
<input id="url" name="url"  type="url" placeholder="Enter URL" />
<input id="submit" name="submit" type="submit" value="Submit" />
</form>
<h2>{{operation}} {{company_name}} {{url}} {{table}} </h2>
</body>
</html>

